==> dokuwiki-2014.09.29b.tgz: dokuwiki/inc/lang/km/lang.php <==
<?php
/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Ratana Lim <aerorat@yahoo.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '«';
$lang['doublequoteclosing']  = '»';
$lang['singlequoteopening']  = '‘';//&lsquo;
$lang['singlequoteclosing']  = '’';//&rsquo;
$lang['apostrophe']          = '’';//&rsquo;

$lang['btn_edit']   = 'កែទំព័រនេះ';
$lang['btn_source'] = 'បង្ហាងប្រភពទំព័រ';
$lang['btn_show']   = 'បង្ហាងទំព័រ';
$lang['btn_create'] = 'បង្កើតទំព័រនេះ';
$lang['btn_search'] = 'ស្វែងរក';
$lang['btn_save']   = 'រក្សាទុក';
$lang['btn_preview']= 'បង្ហាញ';
$lang['btn_top']    = 'ទៅលើ';
$lang['btn_newer']  = '<<ទំព័រទំនើប';
$lang['btn_older']  = 'ទំព័រថ្មែសម័យ>>';
$lang['btn_revs']   = 'ទំព័រចាស់ៗ';
$lang['btn_recent'] = 'ទំព័រថ្មីៗ';
$lang['btn_upload'] = 'ដាកលើង';
$lang['btn_cancel'] = 'បោះបង់';
$lang['btn_index']  = 'លិបិក្រម';
$lang['btn_secedit']= 'កែ';
$lang['btn_login']  = 'កត់ចូល';
$lang['btn_logout'] = 'កត់ចេញ';
$lang['btn_admin']  = 'អ្នកគ្រប់គ្រង';
$lang['btn_update'] = 'កែឡើង';
$lang['btn_delete'] = 'លុបចោល';
$lang['btn_back']   = 'ត្រឡប់';
$lang['btn_backlink']    = 'ខ្សែចំណងក្រោយ';
$lang['btn_backtomedia'] = 'ទៅប្រព័នឯកសាវិញ';
$lang['btn_subscribe']   = 'ដាក់ដំណឹងផ្លស់ប្តូរ';
$lang['btn_profile']     = 'កែប្រវត្តិរូប';
$lang['btn_reset']       = 'កមណត់ឡើងរិញ';
$lang['btn_draft']    = 'កែគំរោង';
$lang['btn_recover']  = 'ស្រោះគំរោងឡើង';
$lang['btn_draftdel'] = 'លុបគំរោង';
$lang['btn_register'] = 'ចុះឈ្មោះ';//'Register';

$lang['loggedinas'] = 'អ្នកប្រើ:';
$lang['user']       = 'នាមបម្រើ';
$lang['pass']       = 'ពាក្សសម្ងត់';
$lang['newpass']    = 'ពាក្សសម្ងាត់ថ្មី';
$lang['oldpass']    = 'បន្ជាកពាក្សសម្ងាត់';
$lang['passchk']    = 'ម្ដងទាត';
$lang['remember']   = 'ចំណាំខ្ញុំ';
$lang['fullname']   = 'នាមត្រគោល';
$lang['email']      = 'អ៊ីមែល';
$lang['profile']    = 'ប្រវត្តិរូប';// 'User Profile';
$lang['badlogin']   = 'សុំអាទោស​ នាមបំរើ ឬ ពាក្សសម្ងាតមិនត្រវទេ។';
$lang['minoredit']  = 'កែបបណ្តិចបណ្តួច';// 'Minor Changes';
$lang['draftdate']  = 'គំរោង កត់ស្វ័យប្រវត្ត';

$lang['regmissing'] = 'សុំអាទោស​ អ្នកត្រវបំពេញក្របវាល។';
$lang['reguexists'] = 'សុំអាទោស​ នាមប្រើនេះមានរួចហើ។';
$lang['regsuccess'] = 'អ្នកប្រើបានបង្កើតហើយ និងពាក្សសម្ងាតក៏បានផ្ញើទៀត។';
$lang['regsuccess2']= 'អ្នកប្រើបានបង្កើតហើយ។';
$lang['regmailfail']= 'មើលទៅដុចជាមានកំហុសក្នុង....សុំទាកទងអ្នកក្របក្រង';
$lang['regbadmail'] = 'អ៊ីមេលអ្នកសាសេមិនត្រូវបញ្ជរ&mdash;បើអ្នកកិតថានេះជាកំហុសបដិបត្តិ សុំទាកទងអ្នកក្របគ្រោង។';
$lang['regbadpass'] = 'គូពាក្សសម្ងាតមិនដូចគ្នាទេ សមសាកទៀត។';
$lang['regpwmail']  = 'ពាក្សសម្ងាតអ្នក';
$lang['reghere']    = 'អ្នកឥតមានបញ្ជីនាមបម្រើទេ?  សុំចល់ចុះឈ្មោះធ្វើគណនីសម្របប្រើប្រស';

$lang['profna']       = 'មិនអាចកែ';
$lang['profnochange'] = 'ឥតផ្លាស់ប្ដូរ ក្មានអ្វីធ្វើទេ។';
$lang['profnoempty']  = 'នាមេឬអីមេលទទេ';
$lang['profchanged']  = 'ប្រវត្តិរូបអ្នកប្រើបាន ។';

$lang['pwdforget'] = 'ភ្លិចពាក្សសម្ងាត់ យកមួយទាត។';
$lang['resendna']  = 'វីគីនេះមិនឧបរំផ្ញើពាក្សសម្ងាតម្ដងទៀតទេ។';
$lang['resendpwdmissing'] = 'សុំអាទោស​ អ្នកត្រវបំពេញវាល។';
$lang['resendpwdnouser']  = 'សុំអាទោស​ យាងរកអ្នកប្រើមិនឃើងទេ។';
$lang['resendpwdbadauth'] = 'សុំអាទោស​ រហស្សលេខអនុញ្ញាតពំអាចប្រើបានទេ។ ខ្សែបន្ត';
$lang['resendpwdconfirm'] ='ខ្សែបន្ត';
$lang['resendpwdsuccess'] = 'ពាក្សសម្ងាតអ្នកបានផ្ញើហើយ។';

$lang['txt_upload']   = 'ជ្រើសឯកសារដែលរុញ​ឡើង:';
$lang['txt_filename'] = 'រុញឡើងជា (ស្រេច​ចិត្ត):';
$lang['txt_overwrt']  = 'កត់ពីលើ';//'Overwrite existing file';
$lang['lockedby']     = 'ឥឡូវនេះចកជាប់​:';
$lang['lockexpire']   = 'សោជាប់ផុត​កំណត់ម៉ោង:';
$lang['js']['willexpire']   = 'សោអ្នកចំពោះកែតម្រូវទំព័រនេះ ហួសពែលក្នុងមួយនាទី។\nកុំឲ្យមានជម្លោះ ប្រើ «បង្ហាញ»​ ទៅកំណត់​ឡើង​វិញ។';

$lang['js']['notsavedyet'] = 'កម្រែមិនទានរុក្សាទកត្រូវបោះបង់។\nបន្តទៅទាឬទេ?';
$lang['rssfailed']   = 'មានកំហុសពេលទៅ​ប្រមូល​យកមតិ​ព័ត៌មាន៖ ';
$lang['nothingfound']= 'រកមិនឃើញអ្វីទេ។';

$lang['mediaselect'] = 'ឯកសារមីឌៀ';
$lang['fileupload']  = 'រុញឯកសារមីឌៀឡើង';
$lang['uploadsucc']  = 'រុញចូលមានជ័យ';
$lang['uploadfail']  = 'រុញឡើងបរាជ័យ។ ប្រហែលខុសសិទ្ឋានុញ្ញាត?';
$lang['uploadwrong'] = 'រុញឡើងត្រូវ​បាន​បដិសេធ។ ឯកសារ';
$lang['uploadexist'] = 'ឯកសារមានហើយ។ ឥតមានធ្វើអ្វីទេ។';
$lang['uploadbadcontent'] = 'ធាតុចំរុញឡើងមិនត្រូវកន្ទុយឯកសារ %s ទេ។';
$lang['uploadspam']  = 'ចំរុញឡើង បង្ខាំង ដៅយ  ';
$lang['uploadxss']   = 'ចំរុញឡើង បង្ខាំង  ';
$lang['deletesucc']  = 'ឯកសារ «%s» បានលុបហើយ។';
$lang['deletefail']  = '«%s» មិនអាចលុបទេ&mdashមើល';
$lang['mediainuse']  = 'ឯកសារ «%s» ឥតទានលុបទេ&mdashមានគេកំភងទេជាប់ប្រើ។';
$lang['namespaces']  = 'នាមដ្ឋាន';
$lang['mediafiles']  = 'ឯកសារទំនេនៅក្នុង';

$lang['js']['keepopen']    = 'ទុកបង្អួចបើក ពេលការជម្រើស';
$lang['js']['hidedetails'] = 'បាំង';
$lang['mediausage']  = 'ប្រើ';
$lang['mediaview']   = 'មើលឯកសារដើម';
$lang['mediaroot']   = 'ឫស';
$lang['mediaupload'] = 'រុញឯកសារឡើងទៅនាមដ្ឋាននេះ។ នាមដ្ឋាន «រុញឡើង»';
$lang['mediaextchange'] = 'កន្ទុយឯកសារផ្លាសពី «%s» ទៅ «%s»!';

$lang['reference']   = 'អនុសាសនចំពោះ';
$lang['ref_inuse']   = 'ឯកសារមិនអាចលុបពីព្រោះវានៅចាប់ប្រើដៅទំព័រ៖';
$lang['ref_hidden']  = 'អនុសាសនខ្លះនៅលើទំព័រអ្នកគ្មានសេធអនុញ្ញាត';

$lang['hits']       = 'ត្រូវ';
$lang['quickhits']  = 'ឈ្មោះទំព័រប្រៀបដូច';
$lang['toc']        = 'មាតិកា';
$lang['current']    = 'ឥឡៅវ';
$lang['yours']      = 'តំណែអ្នាក';
$lang['diff']       = 'បង្ហាងអសទិសភាពជាមួយតំណែឥឡូវ ';
$lang['line']       = 'ខ្សែ';
$lang['breadcrumb'] = 'ដាន:';
$lang['youarehere'] = 'ដាន:';
$lang['lastmod']    = 'ពេលកែចុងក្រោយ:';
$lang['by']         = 'និពន្ឋដោយ';
$lang['deleted']    = 'យកចេញ';
$lang['created']    = 'បង្កើត';
$lang['external_edit'] = 'កំរេពីក្រៅ';
$lang['summary']    = 'កែតម្រា';

$lang['mail_newpage']  = 'ថែមទំព័រ';
$lang['mail_changed']  = 'ទំព័រប្រែប្រួល';
$lang['mail_new_user'] = 'អ្នកប្រើថ្មី';
$lang['mail_upload']   = 'រុញអក្សាលើង';

$lang['qb_bold']    = 'ឃ្វាមក្រស';
$lang['qb_italic']  = 'ឃ្វាមជ្រៀង';
$lang['qb_underl']  = 'ឃ្វាម';
$lang['qb_code']    = 'ឃ្វាមក្បួន';
$lang['qb_strike']  = 'ឃ្វាម';
$lang['qb_h1']      = 'និវេទន៍ទី១';
$lang['qb_h2']      = 'និវេទន៍ទី២';
$lang['qb_h3']      = 'និវេទន៍ទី៣';
$lang['qb_h4']      = 'និវេទន៍ទី៤';
$lang['qb_h5']      = 'និវេទន៍ទី៥';
$lang['qb_link']    = 'ខ្សែបន្តក្នុង';
$lang['qb_extlink'] = 'ខ្សែបន្តក្រៅ';
$lang['qb_hr']      = 'បន្ទាផ្ដេក';
$lang['qb_ol']      = 'តារាងត្រៀប';
$lang['qb_ul']      = 'តារាងអត្រៀប';
$lang['qb_media']   = 'បន្ថែមរូនឹងឯកសារឥទៀត';
$lang['qb_sig']     = 'ស៊កហត្ថលេខា';
$lang['qb_smileys'] = 'សញ្ញាអារម្មណ៍';
$lang['qb_chars']   = 'អក្ខរៈពិសេស';

$lang['js']['del_confirm']= 'លុប';
$lang['admin_register']= 'តែមអ្នកប្រើ';//'Add new user';

$lang['metaedit']    = 'កែទិន្នន័យអរូប';//'Edit Metadata';
$lang['metasaveerr'] = 'ពំអាចកត់រទិន្នន័យអរូប';//'Writing metadata failed';
$lang['metasaveok']  = 'ទិន្នន័យអរូប';
$lang['btn_img_backto']  = 'ថយក្រោយ%s';
$lang['img_title']   = 'អភិធេយ្យ:';
$lang['img_caption'] = 'ចំណងជើង:';
$lang['img_date']    = 'ថ្ងៃខែ:';//'Date';
$lang['img_fname']   = 'ឈ្មោះឯកសារ:';
$lang['img_fsize']   = 'ទំហំ:';//'Size';
$lang['img_artist']  = 'អ្នកថតរូប:';
$lang['img_copyr']   = 'រក្សា​សិទ្ធិ:';
$lang['img_format']  = 'ធុនប្រភេទ:';
$lang['img_camera']  = 'គ្រឿងថត:';
$lang['img_keywords']= 'មេពាក្ស:';//'Keywords';

/* auth.class language support */
$lang['authtempfail']    = 'ការផ្ទៀងផ្ទាត់​ភាព​​ត្រឹមត្រូវឥតដំនេ។ ប្រើ ....';

/* installer strings */
$lang['i_chooselang'] = 'រើសពាស្សាអ្នក';
$lang['i_installer']  = 'ដំឡើងឌោគូវីគី';
$lang['i_wikiname']   = 'នាមវីគី';
$lang['i_enableacl']  = 'បើកប្រើ (អនុសាស)';
$lang['i_superuser']  = 'អ្នកកំពូល';
$lang['i_problems']   = 'កម្មវិធី​ដំឡើងបានប៉ះឧបសគ្គ។ អ្នកមិនអាចបន្តទៅទៀត ដល់អ្នកជួសជុលវា។';
$lang['i_modified']   = '';
$lang['i_funcna']     = '<code>%s</code> ';
$lang['i_permfail']   = '<code>%s</code> មិនអាចសាស';
$lang['i_confexists'] = '<code>%s</code> មានហាយ';
$lang['i_writeerr']   = 'មិនអាចបណ្កើ<code>%s</code>។ អ្នកត្រវការពិនិត្យអធិក្រឹតិរបស់ថតនឹងឯកសារ។';
$lang['i_badhash']    = '(hash=<code>%s</code>)';
$lang['i_badval']     = '<code>%s</code>&mdash;';
$lang['i_success']    = '';
$lang['i_failure']    = 'ពលសាសារ';
$lang['i_policy']     = 'បញ្ជីអនុញ្ញតផ្ដើម';
$lang['i_pol0']       = 'វីគីបើកចំហ';
$lang['i_pol1']       = 'វីគីសធារណៈ';
$lang['i_pol2']       = 'វីគីបិទជិត';

$lang['i_retry']      = 'ម្តងទៀត';

//Setup VIM: ex: et ts=2 :

==> dokuwiki-2018.04.22ap1.tgz: dokuwiki/inc/lang/km/lang.php <==
<?php
/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Ratana Lim <aerorat@yahoo.com>
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';
$lang['doublequoteopening']  = '«';
$lang['doublequoteclosing']  = '»';
$lang['singlequoteopening']  = '‘';//&lsquo;
$lang['singlequoteclosing']  = '’';//&rsquo;
$lang['apostrophe']          = '’';//&rsquo;

$lang['btn_edit']   = 'កែទំព័រនេះ';
$lang['btn_source'] = 'បង្ហាងប្រភពទំព័រ';
$lang['btn_show']   = 'បង្ហាងទំព័រ';
$lang['btn_create'] = 'បង្កើតទំព័រនេះ';
$lang['btn_search'] = 'ស្វែងរក';
$lang['btn_save']   = 'រក្សាទុក';
$lang['btn_preview']= 'បង្ហាញ';
$lang['btn_top']    = 'ទៅលើ';
$lang['btn_newer']  = '<<ទំព័រទំនើប';
$lang['btn_older']  = 'ទំព័រថ្មែសម័យ>>';
$lang['btn_revs']   = 'ទំព័រចាស់ៗ';
$lang['btn_recent'] = 'ទំព័រថ្មីៗ';
$lang['btn_upload'] = 'ដាកលើង';
$lang['btn_cancel'] = 'បោះបង់';
$lang['btn_index']  = 'លិបិក្រម';
$lang['btn_secedit']= 'កែ';
$lang['btn_login']  = 'កត់ចូល';
$lang['btn_logout'] = 'កត់ចេញ';
$lang['btn_admin']  = 'អ្នកគ្រប់គ្រង';
$lang['btn_update'] = 'កែឡើង';
$lang['btn_delete'] = 'លុបចោល';
$lang['btn_back']   = 'ត្រឡប់';
$lang['btn_backlink']    = 'ខ្សែចំណងក្រោយ';
$lang['btn_subscribe']   = 'ដាក់ដំណឹងផ្លស់ប្តូរ';
$lang['btn_profile']     = 'កែប្រវត្តិរូប';
$lang['btn_reset']       = 'កមណត់ឡើងរិញ';
$lang['btn_draft']    = 'កែគំរោង';
$lang['btn_recover']  = 'ស្រោះគំរោងឡើង';
$lang['btn_draftdel'] = 'លុបគំរោង';
$lang['btn_register'] = 'ចុះឈ្មោះ';//'Register';

$lang['loggedinas'] = 'អ្នកប្រើ:';
$lang['user']       = 'នាមបម្រើ';
$lang['pass']       = 'ពាក្សសម្ងត់';
$lang['newpass']    = 'ពាក្សសម្ងាត់ថ្មី';
$lang['oldpass']    = 'បន្ជាកពាក្សសម្ងាត់';
$lang['passchk']    = 'ម្ដងទាត';
$lang['remember']   = 'ចំណាំខ្ញុំ';
$lang['fullname']   = 'នាមត្រគោល';
$lang['email']      = 'អ៊ីមែល';
$lang['profile']    = 'ប្រវត្តិរូប';// 'User Profile';
$lang['badlogin']   = 'សុំអាទោស​ នាមបំរើ ឬ ពាក្សសម្ងាតមិនត្រវទេ។';
$lang['minoredit']  = 'កែបបណ្តិចបណ្តួច';// 'Minor Changes';
$lang['draftdate']  = 'គំរោង កត់ស្វ័យប្រវត្ត';

$lang['regmissing'] = 'សុំអាទោស​ អ្នកត្រវបំពេញក្របវាល។';
$lang['reguexists'] = 'សុំអាទោស​ នាមប្រើនេះមានរួចហើ។';
$lang['regsuccess'] = 'អ្នកប្រើបានបង្កើតហើយ និងពាក្សសម្ងាតក៏បានផ្ញើទៀត។';
$lang['regsuccess2']= 'អ្នកប្រើបានបង្កើតហើយ។';
$lang['regmailfail']= 'មើលទៅដុចជាមានកំហុសក្នុង....សុំទាកទងអ្នកក្របក្រង';
$lang['regbadmail'] = 'អ៊ីមេលអ្នកសាសេមិនត្រូវបញ្ជរ—បើអ្នកកិតថានេះជាកំហុសបដិបត្តិ សុំទាកទងអ្នកក្របគ្រោង។';
$lang['regbadpass'] = 'គូពាក្សសម្ងាតមិនដូចគ្នាទេ សមសាកទៀត។';
$lang['regpwmail']  = 'ពាក្សសម្ងាតអ្នក';
$lang['reghere']    = 'អ្នកឥតមានបញ្ជីនាមបម្រើទេ?  សុំចល់ចុះឈ្មោះធ្វើគណនីសម្របប្រើប្រស';

$lang['profna']       = 'មិនអាចកែ';
$lang['profnochange'] = 'ឥតផ្លាស់ប្ដូរ ក្មានអ្វីធ្វើទេ។';
$lang['profnoempty']  = 'នាមេឬអីមេលទទេ';
$lang['profchanged']  = 'ប្រវត្តិរូបអ្នកប្រើបាន ។';

$lang['pwdforget'] = 'ភ្លិចពាក្សសម្ងាត់ យកមួយទាត។';
$lang['resendna']  = 'វីគីនេះមិនឧបរំផ្ញើពាក្សសម្ងាតម្ដងទៀតទេ។';
$lang['resendpwdmissing'] = 'សុំអាទោស​ អ្នកត្រវបំពេញវាល។';
$lang['resendpwdnouser']  = 'សុំអាទោស​ យាងរកអ្នកប្រើមិនឃើងទេ។';
$lang['resendpwdbadauth'] = 'សុំអាទោស​ រហស្សលេខអនុញ្ញាតពំអាចប្រើបានទេ។ ខ្សែបន្ត';
$lang['resendpwdconfirm'] ='ខ្សែបន្ត';
$lang['resendpwdsuccess'] = 'ពាក្សសម្ងាតអ្នកបានផ្ញើហើយ។';

$lang['txt_upload']   = 'ជ្រើសឯកសារដែលរុញ​ឡើង:';
$lang['txt_filename'] = 'រុញឡើងជា (ស្រេច​ចិត្ត):';
$lang['txt_overwrt']  = 'កត់ពីលើ';//'Overwrite existing file';
$lang['lockedby']     = 'ឥឡូវនេះចកជាប់​:';
$lang['lockexpire']   = 'សោជាប់ផុត​កំណត់ម៉ោង:';
$lang['js']['willexpire']   = 'សោអ្នកចំពោះកែតម្រូវទំព័រនេះ ហួសពែលក្នុងមួយនាទី។\nកុំឲ្យមានជម្លោះ ប្រើ «បង្ហាញ»​ ទៅកំណត់​ឡើង​វិញ។';

$lang['js']['notsavedyet'] = 'កម្រែមិនទានរុក្សាទកត្រូវបោះបង់។\nបន្តទៅទាឬទេ?';
$lang['rssfailed']   = 'មានកំហុសពេលទៅ​ប្រមូល​យកមតិ​ព័ត៌មាន៖ ';
$lang['nothingfound']= 'រកមិនឃើញអ្វីទេ។';

$lang['mediaselect'] = 'ឯកសារមីឌៀ';
$lang['uploadsucc']  = 'រុញចូលមានជ័យ';
$lang['uploadfail']  = 'រុញឡើងបរាជ័យ។ ប្រហែលខុសសិទ្ឋានុញ្ញាត?';
$lang['uploadwrong'] = 'រុញឡើងត្រូវ​បាន​បដិសេធ។ ឯកសារ';
$lang['uploadexist'] = 'ឯកសារមានហើយ។ ឥតមានធ្វើអ្វីទេ។';
$lang['uploadbadcontent'] = 'ធាតុចំរុញឡើងមិនត្រូវកន្ទុយឯកសារ %s ទេ។';
$lang['uploadspam']  = 'ចំរុញឡើង បង្ខាំង ដៅយ  ';
$lang['uploadxss']   = 'ចំរុញឡើង បង្ខាំង  ';
$lang['deletesucc']  = 'ឯកសារ «%s» បានលុបហើយ។';
$lang['deletefail']  = '«%s» មិនអាចលុបទេ—មើល';
$lang['mediainuse']  = 'ឯកសារ «%s» ឥតទានលុបទេ—មានគេកំភងទេជាប់ប្រើ។';
$lang['namespaces']  = 'នាមដ្ឋាន';
$lang['mediafiles']  = 'ឯកសារទំនេនៅក្នុង';

$lang['js']['keepopen']    = 'ទុកបង្អួចបើក ពេលការជម្រើស';
$lang['js']['hidedetails'] = 'បាំង';
$lang['mediausage']  = 'ប្រើ';
$lang['mediaview']   = 'មើលឯកសារដើម';
$lang['mediaroot']   = 'ឫស';
$lang['mediaupload'] = 'រុញឯកសារឡើងទៅនាមដ្ឋាននេះ។ នាមដ្ឋាន «រុញឡើង»';
$lang['mediaextchange'] = 'កន្ទុយឯកសារផ្លាសពី «%s» ទៅ «%s»!';

$lang['reference']   = 'អនុសាសនចំពោះ';
$lang['ref_inuse']   = 'ឯកសារមិនអាចលុបពីព្រោះវានៅចាប់ប្រើដៅទំព័រ៖';
$lang['ref_hidden']  = 'អនុសាសនខ្លះនៅលើទំព័រអ្នកគ្មានសេធអនុញ្ញាត';

$lang['hits']       = 'ត្រូវ';
$lang['quickhits']  = 'ឈ្មោះទំព័រប្រៀបដូច';
$lang['toc']        = 'មាតិកា';
$lang['current']    = 'ឥឡៅវ';
$lang['yours']      = 'តំណែអ្នាក';
$lang['diff']       = 'បង្ហាងអសទិសភាពជាមួយតំណែឥឡូវ ';
$lang['line']       = 'ខ្សែ';
$lang['breadcrumb'] = 'ដាន:';
$lang['youarehere'] = 'ដាន:';
$lang['lastmod']    = 'ពេលកែចុងក្រោយ:';
$lang['by']         = 'និពន្ឋដោយ';
$lang['deleted']    = 'យកចេញ';
$lang['created']    = 'បង្កើត';
$lang['external_edit'] = 'កំរេពីក្រៅ';
$lang['summary']    = 'កែតម្រា';

$lang['mail_newpage']  = 'ថែមទំព័រ';
$lang['mail_changed']  = 'ទំព័រប្រែប្រួល';
$lang['mail_new_user'] = 'អ្នកប្រើថ្មី';
$lang['mail_upload']   = 'រុញអក្សាលើង';

$lang['qb_bold']    = 'ឃ្វាមក្រស';
$lang['qb_italic']  = 'ឃ្វាមជ្រៀង';
$lang['qb_underl']  = 'ឃ្វាម';
$lang['qb_code']    = 'ឃ្វាមក្បួន';
$lang['qb_strike']  = 'ឃ្វាម';
$lang['qb_h1']      = 'និវេទន៍ទី១';
$lang['qb_h2']      = 'និវេទន៍ទី២';
$lang['qb_h3']      = 'និវេទន៍ទី៣';
$lang['qb_h4']      = 'និវេទន៍ទី៤';
$lang['qb_h5']      = 'និវេទន៍ទី៥';
$lang['qb_link']    = 'ខ្សែបន្តក្នុង';
$lang['qb_extlink'] = 'ខ្សែបន្តក្រៅ';
$lang['qb_hr']      = 'បន្ទាផ្ដេក';
$lang['qb_ol']      = 'តារាងត្រៀប';
$lang['qb_ul']      = 'តារាងអត្រៀប';
$lang['qb_media']   = 'បន្ថែមរូនឹងឯកសារឥទៀត';
$lang['qb_sig']     = 'ស៊កហត្ថលេខា';
$lang['qb_smileys'] = 'សញ្ញាអារម្មណ៍';
$lang['qb_chars']   = 'អក្ខរៈពិសេស';

$lang['js']['del_confirm']= 'លុប';

$lang['metaedit']    = 'កែទិន្នន័យអរូប';//'Edit Metadata';
$lang['metasaveerr'] = 'ពំអាចកត់រទិន្នន័យអរូប';//'Writing metadata failed';
$lang['metasaveok']  = 'ទិន្នន័យអរូប';
$lang['btn_img_backto']  = 'ថយក្រោយ%s';
$lang['img_title']   = 'អភិធេយ្យ:';
$lang['img_caption'] = 'ចំណងជើង:';
$lang['img_date']    = 'ថ្ងៃខែ:';//'Date';
$lang['img_fname']   = 'ឈ្មោះឯកសារ:';
$lang['img_fsize']   = 'ទំហំ:';//'Size';
$lang['img_artist']  = 'អ្នកថតរូប:';
$lang['img_copyr']   = 'រក្សា​សិទ្ធិ:';
$lang['img_format']  = 'ធុនប្រភេទ:';
$lang['img_camera']  = 'គ្រឿងថត:';
$lang['img_keywords']= 'មេពាក្ស:';//'Keywords';

/* auth.class language support */
$lang['authtempfail']    = 'ការផ្ទៀងផ្ទាត់​ភាព​​ត្រឹមត្រូវឥតដំនេ។ ប្រើ ....';

/* installer strings */
$lang['i_chooselang'] = 'រើសពាស្សាអ្នក';
$lang['i_installer']  = 'ដំឡើងឌោគូវីគី';
$lang['i_wikiname']   = 'នាមវីគី';
$lang['i_enableacl']  = 'បើកប្រើ (អនុសាស)';
$lang['i_superuser']  = 'អ្នកកំពូល';
$lang['i_problems']   = 'កម្មវិធី​ដំឡើងបានប៉ះឧបសគ្គ។ អ្នកមិនអាចបន្តទៅទៀត ដល់អ្នកជួសជុលវា។';
$lang['i_modified']   = '';
$lang['i_permfail']   = '<code>%s</code> មិនអាចសាស';
$lang['i_confexists'] = '<code>%s</code> មានហាយ';
$lang['i_writeerr']   = 'មិនអាចបណ្កើ<code>%s</code>។ អ្នកត្រវការពិនិត្យអធិក្រឹតិរបស់ថតនឹងឯកសារ។';
$lang['i_success']    = '';
$lang['i_failure']    = 'ពលសាសារ';
$lang['i_policy']     = 'បញ្ជីអនុញ្ញតផ្ដើម';
$lang['i_pol0']       = 'វីគីបើកចំហ';
$lang['i_pol1']       = 'វីគីសធារណៈ';
$lang['i_pol2']       = 'វីគីបិទជិត';

$lang['i_retry']      = 'ម្តងទៀត';

//Setup VIM: ex: et ts=2 :
$lang['email_signature_text'] = 'អ៊ីមេលនេះបន្ចេអពីឌោគូវីគីនៅ
@DOKUWIKIURL@';
